==> RESTEasyCLI-0.7.0-py3-none-any.whl: resteasycli/schema/auth.py <==
from marshmallow import fields, Schema, ValidationError, post_load

from resteasycli.schema.common import OrderedDictField
from resteasycli.schema.workspace import WorkspaceFileSchema


class BasicAuthSchema(Schema):
    '''Schema for basic auth'''
    username = fields.Str(required=True)
    password = fields.Str(required=True)
    class Meta:
        ordered = True

class TokenAuthSchema(Schema):
    '''Schema for token auth'''
    header = fields.Str(required=True)
    value = fields.Str(required=True)
    class Meta:
        ordered = True

class AuthSchema(Schema):
    '''Schema for a saved request format'''
    type = fields.Str(required=True)
    credentials = fields.Dict(required=True, keys=fields.Str())

    @post_load(pass_original=True)
    def validate_credentials(self, data, _):
        '''Validate credentials using approtriate schema'''
        if data['type'] == 'basic':
            data['credentials'] = BasicAuthSchema().load(data['credentials'])
        elif data['type'] == 'token':
            data['credentials'] = TokenAuthSchema().load(data['credentials'])
        else:
            raise ValidationError('{}: invalid authentication type'.format(data['type']))
        return data
    
    class Meta:
        ordered = True

class AuthFileSchema(WorkspaceFileSchema):
    '''Schema for auth file format'''
    auth = OrderedDictField(
        required=True,
        keys=fields.Str(),
        values=fields.Nested(AuthSchema))

    class Meta:
        ordered = True

==> RESTEasyCLI-0.9.4-py3-none-any.whl: resteasycli/schema/auth.py <==
from marshmallow import fields, Schema, ValidationError, post_load

from resteasycli.schema.common import OrderedDictField
from resteasycli.schema.workspace import WorkspaceFileSchema


class BasicAuthSchema(Schema):
    '''Schema for basic auth'''
    username = fields.Str(required=True)
    password = fields.Str(required=True)
    class Meta:
        ordered = True

class TokenAuthSchema(Schema):
    '''Schema for token auth'''
    token_type = fields.Str(required=True)
    token_hash = fields.Str(required=True)
    class Meta:
        ordered = True

class AuthSchema(Schema):
    '''Schema for a saved request format'''
    type = fields.Str(required=True)
    credentials = fields.Dict(required=True, keys=fields.Str())

    @post_load(pass_original=True)
    def validate_credentials(self, data, _):
        '''Validate credentials using approtriate schema'''
        if data['type'] == 'basic':
            data['credentials'] = BasicAuthSchema().load(data['credentials'])
        elif data['type'] == 'token':
            data['credentials'] = TokenAuthSchema().load(data['credentials'])
        else:
            raise ValidationError('{}: invalid authentication type'.format(data['type']))
        return data

    class Meta:
        ordered = True

class AuthFileSchema(WorkspaceFileSchema):
    '''Schema for auth file format'''
    auth = OrderedDictField(
        required=True,
        keys=fields.Str(),
        values=fields.Nested(AuthSchema))

    class Meta:
        ordered = True
